@@ -126,6 +126,10 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
 WidgetFactory.createDialog = function(basePath, uiFile, parent) {
     var dialog = WidgetFactory.createWidget(basePath, uiFile, parent);
 
+    var flags = dialog.windowFlags();
+    flags = new Qt.WindowFlags(flags & ~(Qt.WindowContextHelpButtonHint));
+    dialog.setWindowFlags(flags);
+
     // a global function might be defined to do additional
     // initilization for all dialogs (e.g. for testing purposes):
     if (typeof(initDialog)!=="undefined") {
@@ -247,6 +251,9 @@ WidgetFactory.saveState = function(widget, group, document, map) {
             //value = [c.text, c.getDefaultUnit()];
             value = c.text;
         }
+        else if (isOfType(c, RMathComboBox)) {
+            value = c.currentText;
+        }
         else if (isOfType(c, QCheckBox)) {
             value = c.checked;
         }
@@ -565,6 +572,24 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, RMathComboBox)) {
+            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            if (isNull(c.defaultValue)) {
+                //c.defaultValue = [c.text, c.getDefaultUnit()];
+                c.defaultValue = c.currentText;
+                c.slotTextChanged(c.currentText);
+            }
+            if (!isNull(value)) {
+                if (isString(value)) {
+                    c.currentText = value;
+                }
+                else {
+                    c.currentText = "%1".arg(value);
+                }
+            }
+            continue;
+        }
         if (isOfType(c, QToolButton) || isOfType(c, QPushButton)) {
 
             if (!c.group() && !c.autoExclusive) {
@@ -618,7 +643,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             else {
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
                 c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-                c.checked = (c.objectName == value);
+                if (value==="true") {
+                    c.checked = value;
+                }
+                else {
+                    c.checked = (c.objectName == value);
+                }
             }
             continue;
         }
@@ -904,7 +934,8 @@ WidgetFactory.processChildren = function(c) {
         isOfType(c, QComboBox) ||
         isOfType(c, QFontComboBox) ||
         isOfType(c, QPlainTextEdit) ||
-        isOfType(c, RMathLineEdit)) {
+        isOfType(c, RMathLineEdit) ||
+        isOfType(c, RMathComboBox)) {
 
         return false;
     }
@@ -986,12 +1017,16 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
                 }
             }
             // add line edit or math edit with maximum width:
-            if (isOfType(w, QLineEdit) || isOfType(w, RMathLineEdit)) {
+            if (isOfType(w, QLineEdit) || isOfType(w, RMathLineEdit) || isOfType(w, RMathComboBox)) {
                 if (w.maximumWidth>=1024) {
                     w.maximumWidth = 75;
                 }
             }
 
+            if (isOfType(w, RMathLineEdit) || isOfType(w, RMathComboBox)) {
+                WidgetFactory.initLineEditInfoTools(w);
+            }
+
             a = targetWidget.addWidget(w);
             a.objectName = w.objectName + "Action";
             ret.push(a);
@@ -1008,10 +1043,6 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 };
 
 WidgetFactory.adjustIcons = function(includeBasePath, widget) {
-    if (!RSettings.hasDarkGuiBackground()) {
-        return;
-    }
-
     if (!isFunction(widget.children)) {
         return;
     }
@@ -1020,20 +1051,22 @@ WidgetFactory.adjustIcons = function(includeBasePath, widget) {
     for(var i=0;i<children.length;++i) {
         var w=children[i];
 
-        // adjust icon for dark themes:
+        // adjust icon for theme / dark mode:
         if (isOfType(w, QToolButton)) {
-            var iconFile = includeBasePath + "/" + w.objectName + "-inverse.svg";
-            if (new QFileInfo(iconFile).exists()) {
+            var iconFile = autoIconPath(includeBasePath + "/" + w.objectName + ".svg");
+            if (!isNull(iconFile)) {
                 w.icon = new QIcon(iconFile);
             }
         }
         else {
             WidgetFactory.adjustIcons(includeBasePath, w);
         }
-
     }
 };
 
+WidgetFactory.initLineEditInfoTools = function(mathLineEdit) {
+};
+
 /**
  * Adds an "insert symbol" menu entry to the context menu of the given
  * line edit.
